==> estateplat-common-1.2.4-20210824.022530-851-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSfbGzws.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:wanghaifei@gtmap.cn">wanghaifei</a>
 * @version 1.0, 2021/7/26
 * @description 部级级信息共享-司法部-公证文书信息
 */
@Table(name = "xxgx_sfb_gzws")
public class XxgxSfbGzws {
    @Id
    private String wsid;//文书d
    private String dsrxm;//当事人姓名
    private String dsrzjhm;//当事人证件号码
    private String gzsbh;//公证书编号
    private String gzyxm;//公证员姓名
    private String gzcmc;//公证处名称
    private String gzywlb;//公证业务类别
    private String proid;//项目ID
    private String bjrq;//办结日期
    private Date cxsj;//办结日期

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWsid() {
        return wsid;
    }

    public void setWsid(String wsid) {
        this.wsid = wsid;
    }

    public String getDsrxm() {
        return dsrxm;
    }

    public void setDsrxm(String dsrxm) {
        this.dsrxm = dsrxm;
    }

    public String getDsrzjhm() {
        return dsrzjhm;
    }

    public void setDsrzjhm(String dsrzjhm) {
        this.dsrzjhm = dsrzjhm;
    }

    public String getGzsbh() {
        return gzsbh;
    }

    public void setGzsbh(String gzsbh) {
        this.gzsbh = gzsbh;
    }

    public String getGzyxm() {
        return gzyxm;
    }

    public void setGzyxm(String gzyxm) {
        this.gzyxm = gzyxm;
    }

    public String getGzcmc() {
        return gzcmc;
    }

    public void setGzcmc(String gzcmc) {
        this.gzcmc = gzcmc;
    }

    public String getGzywlb() {
        return gzywlb;
    }

    public void setGzywlb(String gzywlb) {
        this.gzywlb = gzywlb;
    }

    public String getBjrq() {
        return bjrq;
    }

    public void setBjrq(String bjrq) {
        this.bjrq = bjrq;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }
}

==> estateplat-common-1.2.4-20250919.082234-1309-sources.jar: cn/gtmap/estateplat/model/server/core/XxgxSfbGzws.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:wanghaifei@gtmap.cn">wanghaifei</a>
 * @version 1.0, 2021/7/26
 * @description 部级级信息共享-司法部-公证文书信息
 */
@Table(name = "xxgx_sfb_gzws")
public class XxgxSfbGzws {
    @Id
    private String wsid;//文书d
    private String dsrxm;//当事人姓名
    private String dsrzjhm;//当事人证件号码
    private String gzsbh;//公证书编号
    private String gzyxm;//公证员姓名
    private String gzcmc;//公证处名称
    private String gzywlb;//公证业务类别
    private String proid;//项目ID
    private String bjrq;//办结日期
    private Date cxsj;//办结日期

    /**
     *公证事项名称
     */
    private String gzsxmc;

    /**
     *公证类别
     */
    private String gzlb;

    /**
     *事项类别
     */
    private String sxlb;

    /**
     *使用地名称
     */
    private String sydmc;

    /**
     * 出征日期
     */
    private Date czrq;

    /**
     * 受理日期
     */
    private Date slrq;


    /**
     *机构名称
     */
    private String jgmc;

    /**
     *公证书Url
     */
    private String fileUrl;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWsid() {
        return wsid;
    }

    public void setWsid(String wsid) {
        this.wsid = wsid;
    }

    public String getDsrxm() {
        return dsrxm;
    }

    public void setDsrxm(String dsrxm) {
        this.dsrxm = dsrxm;
    }

    public String getDsrzjhm() {
        return dsrzjhm;
    }

    public void setDsrzjhm(String dsrzjhm) {
        this.dsrzjhm = dsrzjhm;
    }

    public String getGzsbh() {
        return gzsbh;
    }

    public void setGzsbh(String gzsbh) {
        this.gzsbh = gzsbh;
    }

    public String getGzyxm() {
        return gzyxm;
    }

    public void setGzyxm(String gzyxm) {
        this.gzyxm = gzyxm;
    }

    public String getGzcmc() {
        return gzcmc;
    }

    public void setGzcmc(String gzcmc) {
        this.gzcmc = gzcmc;
    }

    public String getGzywlb() {
        return gzywlb;
    }

    public void setGzywlb(String gzywlb) {
        this.gzywlb = gzywlb;
    }

    public String getBjrq() {
        return bjrq;
    }

    public void setBjrq(String bjrq) {
        this.bjrq = bjrq;
    }

    public Date getCxsj() {
        return cxsj;
    }

    public void setCxsj(Date cxsj) {
        this.cxsj = cxsj;
    }


    public String getGzsxmc() {
        return gzsxmc;
    }

    public void setGzsxmc(String gzsxmc) {
        this.gzsxmc = gzsxmc;
    }

    public String getGzlb() {
        return gzlb;
    }

    public void setGzlb(String gzlb) {
        this.gzlb = gzlb;
    }

    public String getSxlb() {
        return sxlb;
    }

    public void setSxlb(String sxlb) {
        this.sxlb = sxlb;
    }

    public String getSydmc() {
        return sydmc;
    }

    public void setSydmc(String sydmc) {
        this.sydmc = sydmc;
    }

    public Date getCzrq() {
        return czrq;
    }

    public void setCzrq(Date czrq) {
        this.czrq = czrq;
    }

    public Date getSlrq() {
        return slrq;
    }

    public void setSlrq(Date slrq) {
        this.slrq = slrq;
    }

    public String getJgmc() {
        return jgmc;
    }

    public void setJgmc(String jgmc) {
        this.jgmc = jgmc;
    }

    public String getFileUrl() {
        return fileUrl;
    }

    public void setFileUrl(String fileUrl) {
        this.fileUrl = fileUrl;
    }

}
